###
# -*- coding: iso-8859-15 -*-
# Copyright (c) 2009-2012, Markus Rennings
# All rights reserved.
#
# Fr Folkland Radio, Radios, die daraus entstanden sind und Personen, die
# daran in 2008/2009 beteiligt waren, ist dieses Plugin nicht lizensiert. Somit
# besteht fr diese Personengruppe und Radios keine Erlaubnis, dieses Plugin zu
# benutzen.
#
# If you can't read/understand the German text above, don't worry, you're not
# included in that exception.
#
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions are met:
#
#   * Redistributions of source code must retain the above copyright notice,
#     this list of conditions, and the following disclaimer.
#   * Redistributions in binary form must reproduce the above copyright notice,
#     this list of conditions, and the following disclaimer in the
#     documentation and/or other materials provided with the distribution.
#   * Neither the name of the author of this software nor the name of
#     contributors to this software may be used to endorse or promote products
#     derived from this software without specific prior written consent.
#
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
# AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
# IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
# ARE DISCLAIMED.  IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE
# LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
# CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
# SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
# INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
# CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
# ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
# POSSIBILITY OF SUCH DAMAGE.

###

import re
#import string

import supybot.conf as conf
import supybot.registry as registry


class URLwithPort(registry.String):
    """The value must be an url with port number"""

    __urlRE = re.compile('''https?://((?:\d{1,3}\.){3}\d{1,3}|
            [-_A-Za-z0-9]+(?:\.[-_A-Za-z0-9]+)+):\d{1,5}/?''', re.I | re.X)

    def setValue(self, value):
        if not self.__urlRE.match(value):
            self.error()
        if not value.endswith("/"):
            value = "%s/" % value
        registry.String.setValue(self, value)


class URL(registry.String):
    """The value must be (a comma separated) list of urls"""

    __urlRE = re.compile('''https?://((?:\d{1,3}\.){3}\d{1,3}|
            [-_A-Za-z0-9]+(?:\.[-_A-Za-z0-9]+)+)/?''', re.I | re.X)

    def setValue(self, value):
        if not self.__urlRE.match(value):
            self.error()
        if not value.endswith("/"):
            value = "%s/" % value
        registry.String.setValue(self, value)


def configure(advanced):
    # This will be called by supybot to configure this module.  advanced is
    # a bool that specifies whether the user identified himself as an advanced
    # user or not.  You should effect your configuration by manipulating the
    # registry as appropriate.
    from supybot.questions import expect, anything, something, yn    # __IGNORE_WARNING__ (eric5)
    conf.registerPlugin('Shoutcast', True)




Shoutcast = conf.registerPlugin('Shoutcast')
# This is where your configuration variables (if any) should go.  For example:
# conf.registerGlobalValue(Aena, 'someConfigVariableName',
#     registry.Boolean(False, """Help for someConfigVariableName."""))
conf.registerGlobalValue(Shoutcast, "StreamURL", URLwithPort(
        "http://127.0.0.1:8080/", """URL/IP of the Shoutcast server incl.
        Port and trailing slash"""))

conf.registerGlobalValue(Shoutcast, "Name", registry.NormalizedString(
        "", "The name of that stream"))

conf.registerGlobalValue(Shoutcast, "Homepage", URL(
        "http://localhost.localdomain/", """The homepage of the streams webcast
        station"""))

conf.registerChannelValue(Shoutcast, "ShowStream", registry.Boolean(True,
        """Should the stream command work?"""))

conf.registerChannelValue(Shoutcast, "ShowTitle", registry.Boolean(True,
        """Should the title command work?"""))

conf.registerChannelValue(Shoutcast, "ShowListeners", registry.Boolean(True,
        """Should the listener command work?"""))

conf.registerChannelValue(Shoutcast, "ShowProgram", registry.Boolean(True,
        """Show the program's name?"""))

conf.registerChannelValue(Shoutcast, "ShowPeak", registry.Boolean(True, """Show
        the listener's peak?"""))

conf.registerChannelValue(Shoutcast, "ShowMaxListeners", registry.Boolean(True,
        """Show the maximum listener slots?"""))

conf.registerChannelValue(Shoutcast, "ShowAll", registry.Boolean(True,
        """Should the all command work?"""))

conf.registerChannelValue(Shoutcast, "ShowLast", registry.Boolean(True,
        """Should the last command work?"""))

conf.registerChannelValue(Shoutcast, "ShowKbps", registry.Boolean(True,
        """Should the kbps rate of the server be displayed?"""))

conf.registerChannelValue(Shoutcast, "ShowUnique", registry.Boolean(True,
        """Should the unique listeners (ips) be shown?"""))

conf.registerChannelValue(Shoutcast, "Announce", registry.Boolean(False,
        """Should new songs be announced automatically in the channel? You need
        also to change the UpdateIntervall value for this to work"""))

conf.registerGlobalValue(Shoutcast, "UpdateIntervall",
        registry.NonNegativeInteger(0, """Time intervall, in which the data
        from the shoutcast server should be updated; in seconds; 0 to
        disable"""))

conf.registerChannelValue(Shoutcast, "AnnounceText", registry.NormalizedString(
        "Current Song: @@SONG@@", """The text used to announce new songs to the
        channel. @@SONG@@ will be replaced with the song's name and @@STREAM@@
        with the stream's name, @@TIME@@ with the timestamp configured in
        timestampFormat."""))

conf.registerChannelValue(Shoutcast, "timestampFormat", registry.String(
        "%H:%M", """The format for the timestamp (@@TIME@@ replacement in
        AnnounceText), see Python documentation on strftime for details"""))

conf.registerChannelValue(Shoutcast, "notActivated", registry.String(
        "Sorry, this is not activated (yet).",  """This text is displayed when
        a command is called which is deactivated"""))

conf.registerChannelValue(Shoutcast, "allText", registry.String(
        "On @@station@@ @@listeners@@/@@maxlisteners@@ (@@unique@@) are \
listening to @@title@@ (in @@kbps@@ kbps). The listeners peak is @@peak@@. \
Current program is @@program@@.",  """The text which the 'all' command
        is showing; the following tokens will be replaced if activated by Show*
        in config: @@station@@, @@listeners@@, @@maxlisteners@@, @@title@@,
        @@kbps@@, @@peak@@, @@program@@, @@unique@@"""))

conf.registerChannelValue(Shoutcast, "streamText", registry.String(
        "You could listen to @@station@@ on @@mrl@@listen.pls",
        """Text which is shown on calling 'stream', @@station@@ and @@mrl@@
        will be replaced."""))

conf.registerChannelValue(Shoutcast, "dataRetrError", registry.String(
        "Error retrieving data. Is @@station@@ online?",
        """Error text which is printed when no data could be retrieved.
        @@station@@ will be replaced."""))

conf.registerChannelValue(Shoutcast, "titleText", registry.String(
        "@@station@@ is playing @@title@@",
        """Text for the title command, @@station@@ and @@title@@ will be
        replaced"""))

conf.registerChannelValue(Shoutcast, "listenersText", registry.String(
        "On @@station@@ are @@listeners@@/@@maxlisteners@@ (@@unique@@ unique) listeners",
        """Text for the listeners command; @@station@@ and @@listeners@@ will
        be replaced; @@maxlisteners@@ and @@unique@@ will be replaced if
        enabled by ShowUnique, ShowMaxListeners, ShowListeners"""))

conf.registerChannelValue(Shoutcast, "programText", registry.String(
        "Current programm on @@station@@: @@program@@",
        """Text for the program command, @@station@@ and @@program@@ will be
        replaced"""))

conf.registerChannelValue(Shoutcast, "peakText", registry.String(
        "Current listeners peak on @@station@@: @@peak@@",
        "Text for the peak command, @@station@@ and @@peak@@ will be replaced"))

conf.registerChannelValue(Shoutcast, "maxListenersText", registry.String(
        "Max. @@maxlisteners@@ users could listen to @@station@@",
        """Text for the maxlisteners command, @@maxlisteners@@ and @@station@@
        will be replaced"""))

conf.registerChannelValue(Shoutcast, "lastText", registry.String(
        "Last songs played on @@station@@: @@last@@",
        "Text for the last command, @@station@@ and @@last@@ will be replaced"))

conf.registerChannelValue(Shoutcast, "homepageText", registry.String(
        "You can find @@station@@'s homepage at @@url@@",
        "Text for the homepage command, @@station@@ and @@url@@ will be replaced"))


# vim:set shiftwidth=4 tabstop=4 expandtab textwidth=79:
